@@ -371,7 +371,11 @@ int Mixer_ALSA::openAlsaDevice(const QString& devName)
 }
 
 
-/* setup for select on stdin and the mixer fd */
+/**
+ * Setup for select on stdin and the mixer fd. Every call
+ *
+ * @return A return value from Mixer::MixerError
+ */
 int Mixer_ALSA::setupAlsaPolling()
 {
 	// --- Step 1: Retrieve FD's from ALSALIB
@@ -382,10 +386,22 @@ int Mixer_ALSA::setupAlsaPolling()
 		return Mixer::ERR_OPEN;
 	}
 
-	//if ( countNew != m_sns.size() )
+	/*
+	 * The following "if (true)" read in earlier versions:
+	 *     if ( countNew != m_sns.size() )
+	 *
+	 * This mimics alsamixer behaviour. But reality has proven that
+	 * it is not enough to check for size change. Situations came up where
+	 * the size was identical, but the descriptors changed. This especially
+	 * seems to happen shortly after the kernel loads a soundcard driver and alsalib
+	 * initializes it. Very hard to reproduce, so I do expect some kind of race condition
+	 * there.
+	 * So the final solution is to ALWAYS use the freshest fd's
+	 * delivered by the snd_mixer_poll_descriptors_count() call from above.
+	 */
 	if (true)
 	{
-		// Redo everything if count of FD's have changed (emulating alsamixer behaviour here)
+		// As documentation purpose, please keep the "if (true)" and the comment above explaining it.
 		 while (!m_sns.isEmpty())
 		     delete m_sns.takeFirst();
 
@@ -409,13 +425,11 @@ int Mixer_ALSA::setupAlsaPolling()
 
 
 		// --- Step 2: Create QSocketNotifier's for the FD's
-		//m_sns = new QSocketNotifier*[m_count];
 		for ( int i = 0; i < countNew; ++i )
 		{
-			//kDebug() << "socket " << i;
 			QSocketNotifier* qsn = new QSocketNotifier(m_fds[i].fd, QSocketNotifier::Read);
 			m_sns.append(qsn);
-			connect(m_sns[i], SIGNAL(activated(int)), SLOT(readSetFromHW()), Qt::QueuedConnection);
+			connect(qsn, SIGNAL(activated(int)), SLOT(readSetFromHW()), Qt::QueuedConnection);
 		}
 	}
 
@@ -601,7 +615,7 @@ int Mixer_ALSA::id2num(const QString& id) {
    return num;
 }
 
-bool Mixer_ALSA::prepareUpdateFromHW() {
+bool Mixer_ALSA::hasChangedControls() {
     if ( !m_fds || !m_isOpen )
         return false;
 
@@ -609,40 +623,47 @@ bool Mixer_ALSA::prepareUpdateFromHW() {
     // Poll on fds with 10ms timeout
     // Hint: alsamixer has an infinite timeout, but we cannot do this because we would block
     // the X11 event handling (Qt event loop) with this.
-    int finished = poll(m_fds, m_sns.size(), 10);
-
-    bool updated = false;
-
-    if (finished > 0) {
-        //kDebug() << "Mixer_ALSA::prepareUpdate() 5\n";
+    int finished = poll(m_fds, m_sns.size(), 10); // TODO Could we pass 0 as timeout here? It makes  no real sense to wait!
 
+    if (finished > 0)
+    {
         unsigned short revents;
-
         if (snd_mixer_poll_descriptors_revents(_handle, m_fds, m_sns.size(), &revents) >= 0)
         {
-        //kDebug() << "Mixer_ALSA::prepareUpdate() 6\n";
-
-            if (revents & POLLNVAL) {
+            if (revents & POLLNVAL)
+            {
                 /* Bug 127294 shows, that we receive POLLNVAL when the user
                     unplugs an USB soundcard. Lets close the card. */
                 kDebug() << "Mixer_ALSA::poll() , Error: poll() returns POLLNVAL\n";
                 close();  // Card was unplugged (unplug, driver unloaded)
-                return false;
             }
-            if (revents & POLLERR) {
+            else if (revents & POLLERR)
+            {
                 kDebug() << "Mixer_ALSA::poll() , Error: poll() returns POLLERR\n";
-                return false;
             }
-            if (revents & POLLIN) {
+            else if (revents & POLLIN)
+            {
                 //kDebug() << "Mixer_ALSA::prepareUpdate() 7\n";
-                snd_mixer_handle_events(_handle);
-                updated = true;
+                int eventCount = snd_mixer_handle_events(_handle);
+                if (eventCount >= 0)
+                {
+                	/*
+                	 * Treating everything that is not an error as a change, even if eventCount == 0.
+                	 * For example, when unplugging the headphones from my ThinkPad Laptop ALSA reports "POLLIN" with eventCount == 0.
+                	 * On the other hand, this means I can not likely detect changes
+                	 */
+//                	kDebug()  << "Mixer_ALSA::poll() delivered changes. eventCount=" << eventCount;
+                	return true;
+                }
+                else
+                {
+                    kWarning() << "Mixer_ALSA::poll() , Error: poll() returns POLLIN with errno=" + eventCount;
+                }
             }
         }
     }
 
-    //kDebug() << "Mixer_ALSA::prepareUpdate() 8\n";
-    return updated;
+    return false;
 }
 
 bool Mixer_ALSA::isRecsrcHW( const QString& id )
